v1alpha1

package
v0.73.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 4, 2026 License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Overview

Package v1alpha1 contains functions for validating and converting v1alpha1 structs

Index

Constants

const (
	PkgValidateErrInitNoYOLO              = "sorry, you can't YOLO an init package"
	PkgValidateErrConstant                = "invalid package constant: %w"
	PkgValidateErrYOLONoOCI               = "OCI images not allowed in YOLO"
	PkgValidateErrYOLONoGit               = "git repos not allowed in YOLO"
	PkgValidateErrYOLONoArch              = "cluster architecture not allowed in YOLO"
	PkgValidateErrYOLONoDistro            = "cluster distros not allowed in YOLO"
	PkgValidateErrComponentNameNotUnique  = "component name %q is not unique"
	PkgValidateErrComponentReqDefault     = "component %q cannot be both required and default"
	PkgValidateErrComponentReqGrouped     = "component %q cannot be both required and grouped"
	PkgValidateErrChartNameNotUnique      = "chart name %q is not unique"
	PkgValidateErrChart                   = "invalid chart definition: %w"
	PkgValidateErrManifestNameNotUnique   = "manifest name %q is not unique"
	PkgValidateErrManifest                = "invalid manifest definition: %w"
	PkgValidateErrGroupMultipleDefaults   = "group %q has multiple defaults (%q, %q)"
	PkgValidateErrGroupOneComponent       = "group %q only has one component (%q)"
	PkgValidateErrAction                  = "invalid action: %w"
	PkgValidateErrActionCmdWait           = "action %q cannot be both a command and wait action"
	PkgValidateErrActionClusterNetwork    = "a single wait action must contain only one of cluster or network"
	PkgValidateErrChartName               = "chart %q exceed the maximum length of %d characters"
	PkgValidateErrChartNamespaceMissing   = "chart %q must include a namespace"
	PkgValidateErrChartURLOrPath          = "chart %q must have either a url or localPath"
	PkgValidateErrChartVersion            = "chart %q must include a chart version"
	PkgValidateErrManifestFileOrKustomize = "manifest %q must have at least one file or kustomization"
	PkgValidateErrManifestNameLength      = "manifest %q exceed the maximum length of %d characters"
	PkgValidateErrVariable                = "invalid package variable: %w"
	PkgValidateErrNoComponents            = "package does not contain any compatible components"
	PkgValidateErrActionTemplateOnCreate  = "templating is not supported in onCreate actions"
)

Package errors found during validation.

const (
	// ZarfMaxChartNameLength limits helm chart name size to account for K8s/helm limits and zarf prefix
	ZarfMaxChartNameLength = 40
)

Variables

This section is empty.

Functions

func ValidatePackage

func ValidatePackage(pkg v1alpha1.ZarfPackage) error

ValidatePackage runs all validation checks on the package.

Types

This section is empty.

Jump to