Documentation
¶
Overview ¶
Package v1beta1 contains functions for converting between the public v1beta1 Zarf package and the internal generic representation.
Index ¶
Constants ¶
const ( PkgValidateErrComponentNameNotUnique = "component name %q is not unique" PkgValidateErrChartNameNotUnique = "chart name %q is not unique" PkgValidateErrChart = "invalid chart definition: %w" PkgValidateErrManifestNameNotUnique = "manifest name %q is not unique" PkgValidateErrManifest = "invalid manifest definition: %w" PkgValidateErrAction = "invalid action: %w" PkgValidateErrActionCmdWait = "action %q cannot be both a command and wait action" PkgValidateErrActionClusterNetwork = "a single wait action must contain only one of cluster or network" PkgValidateErrActionSetValueOnDeploy = "setValues is not supported in onCreate actions" PkgValidateErrActionTemplateOnCreate = "templating is not supported in onCreate actions" PkgValidateErrChartName = "chart %q exceed the maximum length of %d characters" PkgValidateErrChartNamespaceMissing = "chart %q must include a namespace" PkgValidateErrManifestFileOrKustomize = "manifest %q must have at least one file or kustomization" PkgValidateErrManifestNameLength = "manifest %q exceed the maximum length of %d characters" PkgValidateErrNoComponents = "package does not contain any compatible components" )
Package errors found during validation.
const (
// ZarfMaxChartNameLength limits helm chart name size to account for K8s/helm limits and zarf prefix
ZarfMaxChartNameLength = 40
)
Variables ¶
This section is empty.
Functions ¶
func ConvertFromGeneric ¶
ConvertFromGeneric converts the internal generic representation to a v1beta1 Package.
Types ¶
type ValidationErrors ¶ added in v0.84.0
type ValidationErrors []error
ValidationErrors contains all errors found during package validation.
func ValidatePackage ¶ added in v0.84.0
func ValidatePackage(pkg v1beta1.Package) ValidationErrors
ValidatePackage runs all validation checks on the package.
func (ValidationErrors) Error ¶ added in v0.84.0
func (errs ValidationErrors) Error() string
Error returns the validation errors separated by newlines.
func (ValidationErrors) Unwrap ¶ added in v0.84.0
func (errs ValidationErrors) Unwrap() []error
Unwrap returns the individual validation errors.
Click to show internal directories.
Click to hide internal directories.